@@ -42,6 +42,7 @@ def _is_feature_enabled(vwo_instance, campaign_key, user_id, **kwargs):
     Keywork Args:
         custom_variables (dict): Custom variables required for segmentation
         variation_targeting_variables (dict): Whitelisting variables to target users
+        should_track_returning_user (bool): should returning user be tracked again.
 
     Returns:
         bool: True if user becomes part of feature test/rollout,
@@ -52,10 +53,15 @@ def _is_feature_enabled(vwo_instance, campaign_key, user_id, **kwargs):
     # Retrieve custom variables
     custom_variables = kwargs.get("custom_variables")
     variation_targeting_variables = kwargs.get("variation_targeting_variables")
+    should_track_returning_user = kwargs.get("should_track_returning_user")
+    
+    if should_track_returning_user is None:
+        should_track_returning_user = vwo_instance.should_track_returning_user or False
 
     if (
         not validate_util.is_valid_string(campaign_key)
         or not validate_util.is_valid_string(user_id)
+        or not validate_util.is_valid_bool(should_track_returning_user)
         or (custom_variables is not None and not validate_util.is_valid_dict(custom_variables))
         or (
             variation_targeting_variables is not None and not validate_util.is_valid_dict(variation_targeting_variables)
@@ -86,12 +92,19 @@ def _is_feature_enabled(vwo_instance, campaign_key, user_id, **kwargs):
         )
         return False
 
+    # check if user has already been tracked
+    is_user_tracked = vwo_instance.variation_decider.identify_tracked_user_from_user_storage(
+        user_id, 
+        campaign_key
+    )
+
     # Get variation
     variation = vwo_instance.variation_decider.get_variation(
         user_id,
         campaign,
         custom_variables=custom_variables,
         variation_targeting_variables=variation_targeting_variables,
+        api_method=constants.API_METHODS.IS_FEATURE_ENABLED,
     )  # noqa: E501
 
     # If no variation, did not become part of feature_test/rollout
@@ -100,21 +113,37 @@ def _is_feature_enabled(vwo_instance, campaign_key, user_id, **kwargs):
 
     # if campaign type is feature_test Send track call to server
     if campaign_type == constants.CAMPAIGN_TYPES.FEATURE_TEST:
-        impression = impression_util.create_impression(
-            vwo_instance.settings_file, campaign.get("id"), variation.get("id"), user_id
-        )
+        # track user if user has not already been tracked 
+        if is_user_tracked is False or should_track_returning_user:
+            impression = impression_util.create_impression(
+                vwo_instance.settings_file, 
+                campaign.get("id"), 
+                variation.get("id"), 
+                user_id
+            )
+
+            vwo_instance.event_dispatcher.dispatch(impression)
+            vwo_instance.logger.log(
+                LogLevelEnum.INFO,
+                LogMessageEnum.INFO_MESSAGES.MAIN_KEYS_FOR_IMPRESSION.format(
+                    file=FILE,
+                    campaign_id=impression.get("experiment_id"),
+                    user_id=impression.get("uId"),
+                    account_id=impression.get("account_id"),
+                    variation_id=impression.get("combination"),
+                ),
+            )
+        else:
+            vwo_instance.logger.log(
+                LogLevelEnum.INFO,
+                LogMessageEnum.INFO_MESSAGES.USER_ALREADY_TRACKED.format(
+                    file=FILE,
+                    user_id=user_id,
+                    campaign_key=campaign_key,
+                    api_method=constants.API_METHODS.IS_FEATURE_ENABLED,
+                )
+            )
 
-        vwo_instance.event_dispatcher.dispatch(impression)
-        vwo_instance.logger.log(
-            LogLevelEnum.INFO,
-            LogMessageEnum.INFO_MESSAGES.MAIN_KEYS_FOR_IMPRESSION.format(
-                file=FILE,
-                campaign_id=impression.get("experiment_id"),
-                user_id=impression.get("uId"),
-                account_id=impression.get("account_id"),
-                variation_id=impression.get("combination"),
-            ),
-        )
         result = variation.get("isFeatureEnabled")
         if result:
             vwo_instance.logger.log(
