@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,25 +13,12 @@
 # limitations under the License.
 
 VARIABLE = {
-    'type': 'object',
-    'properties': {
-        'id': {
-            'type': ['number', 'string']
-        },
-        'key': {
-            'type': ['string']
-        },
-        'value': {
-            'type': ['string', 'number', 'boolean']
-        },
-        'type': {
-            'type': ['string']
-        }
+    "type": "object",
+    "properties": {
+        "id": {"type": ["number", "string"]},
+        "key": {"type": ["string"]},
+        "value": {"type": ["string", "number", "boolean"]},
+        "type": {"type": ["string"]},
     },
-    'required': [
-        'id',
-        'value',
-        'key',
-        'type'
-    ]
+    "required": ["id", "value", "key", "type"],
 }
